pywurfl.algorithms.TwoStepAnalysis

Package pywurfl :: Package algorithms :: Class TwoStepAnalysis |
[hide private]
[frames] | no frames]

# Class TwoStepAnalysis

source code

    object --+
             |
     Algorithm --+
                 |
                TwoStepAnalysis

WURFL Two Step Analysis algorithm based on the Java API implementation

Instance Methods | [hide private]
__init__(self, devices, use_normalized_ua=False) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_determine_handler(self, ua) | source code
Device |
__call__(self, ua, devices=None) Every pywurfl algorithm class must define a __call__ method. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, devices, use_normalized_ua=False) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Parameters: `use_normalized_ua` (bool) - Specify whether or not that this algorithm requires a normalized user agent for search. Overrides: object.__init__

### __call__(self, ua, devices=None) (Call operator) | source code
Every pywurfl algorithm class must define a __call__ method. Parameters: `ua` - The user agent `devices` - The devices object to search Returns: Device Overrides: Algorithm.__call__ (inherited documentation)